@@ -82,6 +82,16 @@ void saphire_set_signal();
     // に必ず呼んでください。
     // 呼ばれないと正しくコマンドは実行されません。
 
+    // 処理しているのは
+    // SIGCHLD, SIGINT, SIGCONT, SIGWINCH, SIGUSR1
+    // 無視しているのは
+    // SIGTTOU, SIGTTIN, SIGTSTP, SIGQUIT, SIGPIPE
+void saphire_set_signal_optc();
+    // saphireを実行中に使うシグナルの設定を設定する。
+    // saphire_shell, saphie_shell3などのsaphireのコードを実行する前
+    // に必ず呼んでください。
+    // 呼ばれないと正しくコマンドは実行されません。
+
     // 処理しているのは
     // SIGCHLD, SIGINT, SIGCONT, SIGWINCH, SIGUSR1
     // 無視しているのは
@@ -134,6 +144,9 @@ int saphire_load_obj(char* fname, sWFd* pipeout, sRFd* pipein, int pipeerr, vect
 void saphire_wait_background_job();
     // バックグランドジョブの状態のチェック
     // ジョブ管理をする場合メインループ中に定期的に実行してください
+void saphire_wait_background_job2();
+    // バックグランドジョブの状態のチェック
+    // ジョブ管理をする場合メインループ中に定期的に実行してください
 extern void (*saphire_job_done)(int job_num, char* job_title);
     // ジョブ管理しているときにジョブが終わったら実行する処理
     // job_numに終わったジョブの番号が入いれて呼ばれる。
@@ -204,6 +217,8 @@ void saphire_add_inner_command(char* name, fInnerCommand fun);
        // 関数ポインタを入力。第一引数はコマンド名
 
 extern volatile BOOL gKitutukiSigInt;  // CTRL-Cが押されたらTRUE
+extern volatile BOOL gKitutukiSigTstp;  // CTRL-Zが押されたらTRUE
+extern volatile BOOL gKitutukiSigCont;  // SITCONT食らったらTRUE
 
 char* saphire_get_local_var(char* name);
     // 現在のスタックフレームでのローカル変数を返す
