@@ -654,20 +654,20 @@ volatile BOOL gSigUser = FALSE;
 void sig_int()
 {
     gKitutukiSigInt = TRUE; 
-//printf("gKitutukiSigInt %d %p\n", gKitutukiSigInt, &gKitutukiSigInt);
+
 #ifdef MDEBUG
 fprintf(stderr, "SIGINT!!\n");
 #endif
 }
 void sig_int_optc()
 {
+    sigchld_block(1);
     gKitutukiSigInt = TRUE; 
-fprintf(stderr, "SIGINT!!\n");
+    sigchld_block(0);
 }
 void sig_tstp()
 {
     gKitutukiSigInt = TRUE; 
-//printf("gKitutukiSigInt %d %p\n", gKitutukiSigInt, &gKitutukiSigInt);
 #ifdef MDEBUG
 fprintf(stderr, "SIGTSTP!!\n");
 #endif
@@ -675,17 +675,18 @@ fprintf(stderr, "SIGTSTP!!\n");
 
 void sig_tstp_optc()
 {
+    sigchld_block(1);
     gKitutukiSigTstp = TRUE;
-    //gKitutukiSigInt = TRUE; 
     kill(getpid(), SIGSTOP);
-    //killpg(getpgid(), SIGTERM);
-//fprintf(stderr, "SIGTSTP!!\n");
+    sigchld_block(0);
 }
 
 void sig_cont_optc()
 {
+    sigchld_block(1);
     gKitutukiSigCont = TRUE;
-    killpg(getpgid(), SIGCONT);
+//    killpg(getpgid(), SIGCONT);
+    sigchld_block(0);
 }
 
 void sig_user()
@@ -2669,7 +2670,7 @@ void saphire_init(enum eAppType app_type, BOOL job_control, enum eRuntimeScript
     gFileHandles = HASH_NEW(100);
     gReadBuffers = HASH_NEW(100);
 
-    setenv("SAPHIRE_VERSION", "1.0.7", 1);
+    setenv("SAPHIRE_VERSION", "1.0.8", 1);
     setenv("SAPHIRE_PROMPT", "> ", 1);
     setenv("SAPHIRE_DOCDIR", DOCDIR, 1);
     char* home = getenv("HOME");
