@@ -252,27 +252,6 @@ void string_trunc(string_obj* self, int n)
     }
 }
 
-//////////////////////////////////////////////////////////////////////////
-// 文字を小文字にする
-//////////////////////////////////////////////////////////////////////////
-void string_tolower(string_obj* self)
-{
-    int i;
-    for(i=0; i<self->mLen; i++) {
-        self->mStr[i] = tolower(self->mStr[i]);
-    }
-}
-
-//////////////////////////////////////////////////////////////////////////
-// 文字を大文字にする
-//////////////////////////////////////////////////////////////////////////
-void string_toupper(string_obj* self)
-{
-    int i;
-    for(i=0; i<self->mLen; i++) {
-        self->mStr[i] = toupper(self->mStr[i]);
-    }
-}
 
 //////////////////////////////////////////////////////////////////////////
 // 部分文字列を得る
@@ -315,3 +294,55 @@ BOOL string_sub_str(string_obj* self, string_obj* result, int index1, int index2
 */
 }
 
+
+//////////////////////////////////////////////////////////////////////////
+// 文字を小文字にする
+//////////////////////////////////////////////////////////////////////////
+void string_tolower(string_obj* self, enum eKanjiCode code)
+{
+    if(code == kSjis || code == kEucjp) {
+        int i;
+        for(i=0; i<self->mLen; i++) {
+            if(is_kanji(code, self->mStr[i])) {
+                self->mStr[i] = self->mStr[i];
+                self->mStr[i+1] = self->mStr[i+1];
+                i++;
+            }
+            else {
+                self->mStr[i] = tolower(self->mStr[i]);
+            }
+        }
+    }
+    else {
+        int i;
+        for(i=0; i<self->mLen; i++) {
+            self->mStr[i] = tolower(self->mStr[i]);
+        }
+    }
+}
+
+//////////////////////////////////////////////////////////////////////////
+// 文字を大文字にする
+//////////////////////////////////////////////////////////////////////////
+void string_toupper(string_obj* self, enum eKanjiCode code)
+{
+    if(code == kSjis || code == kEucjp) {
+        int i;
+        for(i=0; i<self->mLen; i++) {
+            if(is_kanji(code, self->mStr[i])) {
+                self->mStr[i] = self->mStr[i];
+                self->mStr[i+1] = self->mStr[i+1];
+                i++;
+            }
+            else {
+                self->mStr[i] = toupper(self->mStr[i]);
+            }
+        }
+    }
+    else {
+        int i;
+        for(i=0; i<self->mLen; i++) {
+            self->mStr[i] = toupper(self->mStr[i]);
+        }
+    }
+}
